%% Script for calculation of material properties
% input: modified force - displacement diagram
% output: handles.input_data = matrix having one column as displacements
%         and second column as corresponding forces from a measurement

handles_mainGui = getappdata(0,'handles_mainGui');

input_data = getappdata(handles_mainGui, 'input_data');
displacement = input_data(:,1);
force = input_data(:,2);

l = getappdata(handles_mainGui, 'length');
w = getappdata(handles_mainGui, 'width');
h = getappdata(handles_mainGui, 'height');
a = getappdata(handles_mainGui, 'notch');
rho = getappdata(handles_mainGui, 'density');
l_tot = getappdata(handles_mainGui, 'tot_length');
k = getappdata(handles_mainGui, 'beam_stiffness');
wa = getappdata(handles_mainGui, 'notch_width');


%% Calculated values

heff = h-a;
E = f_notched_beam_stiffness2(k,w,h,a,wa,l);
stress_sw = rho*w*h*(l^2-(l_tot-l)^2)*3/(4*w*heff^2);    % stress from self-weight
strain_sw = stress_sw/E;                                 % strain from self-weight
    
strain = [0; 
          strain_sw;
          ones(size(displacement),1)*strain_sw+displacement*6*heff/(l^2)];

stress = [0;
          stress_sw;
          ones(size(force),1)*stress_sw+force*3*l/(2*w*heff^2)];
        
%% Outputs

[maximum_force position] = max(force);
disp_at_max = displacement(position);

[maximum_stress position] = max(stress);
strain_at_max = strain(position);

Gf = f_Gf_RILEM(force,displacement,w,h,a,l_tot,l,rho);

