function Gf = f_Gf_RILEM(forces,displacements,width,height,notch,length_tot,length_eff,rho)

% Evaluation of fracture energy from load - displacement curve using
% RILEM approach
% f_Gf_RILEM(forces,displacements,width,height,notch,length_tot,length_eff,rho)
%
% input: vector with forces from loading test (forces) [N]
%        vector with displacements from loading test (displacements) [m]
%        C/S width [m]
%        C/S height [m]
%        notch depth [m]
%        total length of the beam (length_tot) [m]
%        span of the beam - length between supports (length_eff) [m]
%        density of the material (rho) [N/m^3]
%
% output: fracture energy Gf
%
% written by Venca 12/03/2012 


%% Adding self-weight effect

M = rho*width*height*(length_eff^2/8-(length_tot-length_eff)^2/8);
F_eq = 4*M/length_eff;
k = (forces(10)-forces(1))/(displacements(10)-displacements(1));
delta_sw = F_eq/k;
area = width*(height-notch);

%delta_sw*ones(size(displacements,1),1);

displacements_sw = [0; delta_sw*ones(size(displacements,1),1)+displacements];
forces_sw = [0; F_eq*ones(size(forces,1),1)+forces];

%% Curve fitting and extension of force displacement diagram

poly = 1; % approximation of "tail" by polynomial of order poly

tail = size(displacements_sw,1)-round(0.15*size(displacements_sw,1));
tail_displacements = displacements_sw(tail:end,1);
tail_forces = forces_sw(tail:end,1);

fit = polyfit(tail_displacements,tail_forces,poly);
span = displacements_sw(tail,1):tail_displacements(2,1)-tail_displacements(1,1):tail_displacements(end,1)*50;
span = span';
curve = polyval(fit,span);
lims = find(curve<0);
lim = lims(1);

new_displacements = [displacements_sw(1:tail-1,1);span(1:lim-1,1)];
new_forces = [forces_sw(1:tail-1,1);curve(1:lim-1,1)];

%plot(new_displacements, new_forces)
work = trapz(new_displacements,new_forces);
Gf = work/area;

end